@@ -557,7 +557,7 @@ class Vingd:
                 'autocommit': True
             }))
     
-    def authorized_create_user(self, identities, primary, permissions=None):
+    def authorized_create_user(self, identities=None, primary=None, permissions=None):
         """Creates Vingd user (profile & account), links it with the provided
         identities (to be verified later), and sets the delegate-user
         permissions (creator being the delegate). Returns Vingd user's `huid`
@@ -568,11 +568,15 @@ class Vingd:
             vingd.authorized_create_user(
                 identities={"facebook": "12312312", "mail": "user@example.com"},
                 primary="facebook",
-                delegate_permissions=["get.account.balance", "purchase.object"]
+                permissions=["get.account.balance", "purchase.object"]
             )
         
-        :rtype: ``string``
-        :returns: ``<huid>``
+        If `identities` and `primary` are unspecified, a "zombie" ("headless")
+        account is created (i.e. account with no identities associated,
+        user-unreachable).
+        
+        :rtype: ``dict``
+        :returns: ``{'huid': <huid>}``
         :raises GeneralException:
         :resource: ``id/objects/<oid>/purchases``
         
